update gbm_bo flags 49/55049/1 accepted/tizen/common/20160128.122157 accepted/tizen/ivi/20160218.024322 accepted/tizen/mobile/20151223.053229 accepted/tizen/tv/20151223.053400 accepted/tizen/wearable/20160307.020708 submit/tizen_common/20151229.142028 submit/tizen_common/20151229.144031 submit/tizen_common/20151229.154718 submit/tizen_common/20160104.140200 submit/tizen_common/20160112.103336 submit/tizen_common/20160127.161648 submit/tizen_ivi/20160217.000000 submit/tizen_ivi/20160217.000004 submit/tizen_mobile/20151222.091330 submit/tizen_tv/20151222.090910 submit/tizen_wearable/20160304.133021
authorSangjin Lee <lsj119@samsung.com>
Mon, 21 Dec 2015 11:26:43 +0000 (20:26 +0900)
committerSangjin Lee <lsj119@samsung.com>
Mon, 21 Dec 2015 11:26:43 +0000 (20:26 +0900)
Change-Id: I4bc382b37d3a3df9d7537a4366007df57f0dbe61

src/gbm.h

index 558b512..ca2dd4c 100644 (file)
--- a/src/gbm.h
+++ b/src/gbm.h
@@ -192,10 +192,13 @@ enum gbm_bo_flags {
     */
    GBM_BO_USE_SCANOUT      = (1 << 0),
    /**
-    * Buffer is going to be used as cursor - the dimensions for the buffer
-    * must be 64x64 if this flag is passed.
+    * Buffer is going to be used as cursor
     */
-   GBM_BO_USE_CURSOR_64X64 = (1 << 1),
+   GBM_BO_USE_CURSOR       = (1 << 1),
+   /**
+    * Deprecated
+    */
+   GBM_BO_USE_CURSOR_64X64 = GBM_BO_USE_CURSOR,
    /**
     * Buffer is to be used for rendering - for example it is going to be used
     * as the storage for a color buffer
@@ -203,10 +206,13 @@ enum gbm_bo_flags {
    GBM_BO_USE_RENDERING    = (1 << 2),
    /**
     * Buffer can be used for gbm_bo_write.  This is guaranteed to work
* with GBM_BO_USE_CURSOR_64X64. but may not work for other
* combinations.
     */
    GBM_BO_USE_WRITE    = (1 << 3),
+   /**
+    * Buffer is linear, i.e. not tiled.
+    */
+   GBM_BO_USE_LINEAR = (1 << 4),
 };
 
 int
@@ -203,10 +206,13 @@ enum gbm_bo_flags {
    /**
     * Buffer can be used for gbm_bo_write.  This is guaranteed to work
-    * with GBM_BO_USE_CURSOR_64X64. but may not work for other
-    * combinations.
+    * with GBM_BO_USE_CURSOR. but may not work for other combinations.
     */
    GBM_BO_USE_WRITE    = (1 << 3),